@@ -11,7 +11,7 @@ warnings.filterwarnings(
 )
 
 __all__ = ["Database", "Table", "connect"]
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 
 
 def connect(
@@ -21,6 +21,7 @@ def connect(
     ensure_schema=True,
     row_type=row_type,
     sqlite_wal_mode=True,
+    on_connect_statements=None,
 ):
     """Opens a new connection to a database.
 
@@ -39,8 +40,13 @@ def connect(
     the `ensure_schema` argument. It can also be overridden in a lot of the
     data manipulation methods using the `ensure` flag.
 
+    If you want to run custom SQLite pragmas on database connect, you can add them
+    to on_connect_statements as a set of strings. You can view a full
+    `list of PRAGMAs here`_.
+
     .. _SQLAlchemy Engine URL: http://docs.sqlalchemy.org/en/latest/core/engines.html#sqlalchemy.create_engine
     .. _DB connection timeout: http://docs.sqlalchemy.org/en/latest/core/pooling.html#setting-pool-recycle
+    .. _list of PRAGMAs here: https://www.sqlite.org/pragma.html
     """
     if url is None:
         url = os.environ.get("DATABASE_URL", "sqlite://")
@@ -52,4 +58,5 @@ def connect(
         ensure_schema=ensure_schema,
         row_type=row_type,
         sqlite_wal_mode=sqlite_wal_mode,
+        on_connect_statements=on_connect_statements,
     )
