@@ -2,11 +2,10 @@ import logging
 import threading
 from urllib.parse import parse_qs, urlparse
 
-from sqlalchemy import create_engine
+from sqlalchemy import create_engine, inspect
 from sqlalchemy.sql import text
 from sqlalchemy.schema import MetaData
 from sqlalchemy.util import safe_reraise
-from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy import event
 
 from alembic.migration import MigrationContext
@@ -31,6 +30,7 @@ class Database(object):
         ensure_schema=True,
         row_type=row_type,
         sqlite_wal_mode=True,
+        on_connect_statements=None,
     ):
         """Configure and connect to the database."""
         if engine_kwargs is None:
@@ -57,16 +57,22 @@ class Database(object):
         self.engine = create_engine(url, **engine_kwargs)
         self.is_postgres = self.engine.dialect.name == "postgresql"
         self.is_sqlite = self.engine.dialect.name == "sqlite"
+        if on_connect_statements is None:
+            on_connect_statements = []
 
-        def _enable_sqlite_wal_mode(dbapi_con, con_record):
+        def _run_on_connect(dbapi_con, con_record):
             # reference:
             # https://stackoverflow.com/questions/9671490/how-to-set-sqlite-pragma-statements-with-sqlalchemy
             # https://stackoverflow.com/a/7831210/1890086
-            dbapi_con.execute("PRAGMA journal_mode=WAL")
+            for statement in on_connect_statements:
+                dbapi_con.execute(statement)
 
         if self.is_sqlite and parsed_url.path != "" and sqlite_wal_mode:
             # we only enable WAL mode for sqlite databases that are not in-memory
-            event.listen(self.engine, "connect", _enable_sqlite_wal_mode)
+            on_connect_statements.append("PRAGMA journal_mode=WAL")
+
+        if len(on_connect_statements):
+            event.listen(self.engine, "connect", _run_on_connect)
 
         self.types = Types(is_postgres=self.is_postgres)
         self.url = url
@@ -92,7 +98,10 @@ class Database(object):
     @property
     def inspect(self):
         """Get a SQLAlchemy inspector."""
-        return Inspector.from_engine(self.executable)
+        return inspect(self.executable)
+
+    def has_table(self, name):
+        return self.inspect.has_table(name, schema=self.schema)
 
     @property
     def metadata(self):
