@@ -228,20 +228,21 @@ class Table(object):
         chunk = []
         columns = []
         for index, row in enumerate(rows):
-            chunk.append(row)
-            for col in row.keys():
-                if col not in columns:
-                    columns.append(col)
+            columns.extend(
+                col for col in row.keys() if (col not in columns) and (col not in keys)
+            )
 
             # bindparam requires names to not conflict (cannot be "id" for id)
             for key in keys:
                 row["_%s" % key] = row[key]
+                row.pop(key)
+            chunk.append(row)
 
             # Update when chunk_size is fulfilled or this is the last row
             if len(chunk) == chunk_size or index == len(rows) - 1:
                 cl = [self.table.c[k] == bindparam("_%s" % k) for k in keys]
                 stmt = self.table.update(
-                    whereclause=and_(*cl),
+                    whereclause=and_(True, *cl),
                     values={col: bindparam(col, required=False) for col in columns},
                 )
                 self.db.executable.execute(stmt, chunk)
@@ -414,9 +415,9 @@ class Table(object):
             start, end = value
             return self.table.c[column].between(start, end)
         if op in ("startswith",):
-            return self.table.c[column].like("%" + value)
-        if op in ("endswith",):
             return self.table.c[column].like(value + "%")
+        if op in ("endswith",):
+            return self.table.c[column].like("%" + value)
         return false()
 
     def _args_to_clause(self, args, clauses=()):
@@ -432,7 +433,7 @@ class Table(object):
                     clauses.append(self._generate_clause(column, op, op_value))
             else:
                 clauses.append(self._generate_clause(column, "=", value))
-        return and_(*clauses)
+        return and_(True, *clauses)
 
     def _args_to_order_by(self, order_by):
         orderings = []
